@@ -26,8 +26,8 @@
 
     """
 
-_version = "0.1.1"
-_date = "2008-07-18"
+_version = "0.1.2"
+_date = "2008-07-19"
 _author_name = "Ben Finney"
 _author_email = "ben+python@benfinney.id.au"
 _author = "%(_author_name)s <%(_author_email)s>" % vars()
@@ -35,4 +35,4 @@ _copyright = "Copyright © %s %s" % (
     _date.split('-')[0], _author_name
 )
 _license = "GPL"
-_url = "http://cheeseshop.python.org/pypi/nose-scenario/"
+_url = "http://cheeseshop.python.org/pypi/nose_scenario/"
